@@ -1,8 +1,4 @@
 package Net::Async::Webservice::DHL;
-$Net::Async::Webservice::DHL::VERSION = '1.2.1';
-{
-  $Net::Async::Webservice::DHL::DIST = 'Net-Async-Webservice-DHL';
-}
 use Moo;
 use Types::Standard qw(Str Bool Object Dict Num Optional ArrayRef HashRef Undef Optional);
 use Types::URI qw(Uri);
@@ -23,8 +19,9 @@ use Encode;
 use namespace::autoclean;
 use Future;
 use DateTime;
-use File::ShareDir::ProjectDistDir 'dist_dir', strict => 1;
+use File::ShareDir 'dist_dir';
 use 5.010;
+our $VERSION = '1.2.2'; # VERSION
 
 # ABSTRACT: DHL API client, non-blocking
 
@@ -49,12 +46,12 @@ has base_url => (
     clearer => '_clear_base_url',
 );
 
-sub _trigger_live_mode {
+sub _trigger_live_mode { ## no critic(ProhibitUnusedPrivateSubroutines)
     my ($self) = @_;
 
     $self->_clear_base_url;
 }
-sub _build_base_url {
+sub _build_base_url { ## no critic(ProhibitUnusedPrivateSubroutines)
     my ($self) = @_;
 
     return $base_urls{$self->live_mode ? 'live' : 'test'};
@@ -79,7 +76,7 @@ has _xml_cache => (
     is => 'lazy',
 );
 
-sub _build__xml_cache {
+sub _build__xml_cache { ## no critic(ProhibitUnusedPrivateSubroutines)
     my ($self) = @_;
 
     my $dir = dist_dir('Net-Async-Webservice-DHL');
@@ -311,7 +308,7 @@ Net::Async::Webservice::DHL - DHL API client, non-blocking
 
 =head1 VERSION
 
-version 1.2.1
+version 1.2.2
 
 =head1 SYNOPSIS
 
@@ -546,11 +543,11 @@ L<Net::Async::Webservice::Common::Exception::HTTPError> instance.
 
 =head1 AUTHOR
 
-Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
+Gianni Ceccarelli <dakkar@thenautilus.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Net-a-porter.
+This software is copyright (c) 2016 by Net-a-porter.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
