@@ -1,16 +1,12 @@
 package Net::Async::Webservice::DHL::Exception;
-$Net::Async::Webservice::DHL::Exception::VERSION = '1.2.1';
-{
-  $Net::Async::Webservice::DHL::Exception::DIST = 'Net-Async-Webservice-DHL';
-}
 use strict;
+use warnings;
+our $VERSION = '1.2.2'; # VERSION
+
+# ABSTRACT: exception classes for DHL
 
 
-{package Net::Async::Webservice::DHL::Exception::ConfigError;
-$Net::Async::Webservice::DHL::Exception::ConfigError::VERSION = '1.2.1';
-{
-  $Net::Async::Webservice::DHL::Exception::ConfigError::DIST = 'Net-Async-Webservice-DHL';
-}
+{package Net::Async::Webservice::DHL::Exception::ConfigError; ## no critic(ProhibitMultiplePackages)
  use Moo;
  extends 'Net::Async::Webservice::Common::Exception';
 
@@ -27,11 +23,7 @@ $Net::Async::Webservice::DHL::Exception::ConfigError::VERSION = '1.2.1';
  }
 }
 
-{package Net::Async::Webservice::DHL::Exception::DHLError;
-$Net::Async::Webservice::DHL::Exception::DHLError::VERSION = '1.2.1';
-{
-  $Net::Async::Webservice::DHL::Exception::DHLError::DIST = 'Net-Async-Webservice-DHL';
-}
+{package Net::Async::Webservice::DHL::Exception::DHLError; ## no critic(ProhibitMultiplePackages)
  use Moo;
  extends 'Net::Async::Webservice::Common::Exception';
 
@@ -61,11 +53,11 @@ __END__
 
 =head1 NAME
 
-Net::Async::Webservice::DHL::Exception
+Net::Async::Webservice::DHL::Exception - exception classes for DHL
 
 =head1 VERSION
 
-version 1.2.1
+version 1.2.2
 
 =head1 DESCRIPTION
 
@@ -74,10 +66,6 @@ L</as_string> method should return something readable, with a full
 stack trace.  Their base class is
 L<Net::Async::Webservice::Common::Exception>.
 
-=head1 NAME
-
-Net::Async::Webservice::DHL::Exception - exception classes for DHL
-
 =head1 Classes
 
 =head2 C<Net::Async::Webservice::DHL::Exception::ConfigError>
@@ -114,11 +102,11 @@ Mentions the description and code of the error, plus the stack trace.
 
 =head1 AUTHOR
 
-Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
+Gianni Ceccarelli <dakkar@thenautilus.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Net-a-porter.
+This software is copyright (c) 2016 by Net-a-porter.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
