@@ -1,8 +1,4 @@
 package Net::Async::Webservice::DHL::Types;
-$Net::Async::Webservice::DHL::Types::VERSION = '1.2.1';
-{
-  $Net::Async::Webservice::DHL::Types::DIST = 'Net-Async-Webservice-DHL';
-}
 use strict;
 use warnings;
 use Type::Library
@@ -11,6 +7,7 @@ use Type::Library
 use Type::Utils -all;
 use Types::Standard -types;
 use namespace::autoclean;
+our $VERSION = '1.2.2'; # VERSION
 
 # ABSTRACT: type library for DHL
 
@@ -19,7 +16,7 @@ class_type Address, { class => 'Net::Async::Webservice::DHL::Address' };
 
 enum RouteType, [qw(O D)];
 
-declare CountryCode, as Str, where { length($_) == 2 };
+declare CountryCode, as Str, where { length == 2 };
 
 enum RegionCode, [qw(AP EU AM)];
 
@@ -37,7 +34,7 @@ Net::Async::Webservice::DHL::Types - type library for DHL
 
 =head1 VERSION
 
-version 1.2.1
+version 1.2.2
 
 =head1 DESCRIPTION
 
@@ -52,11 +49,11 @@ Instance of L<Net::Async::Webservice::DHL::Address>.
 
 =head1 AUTHOR
 
-Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
+Gianni Ceccarelli <dakkar@thenautilus.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Net-a-porter.
+This software is copyright (c) 2016 by Net-a-porter.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
