@@ -2,6 +2,9 @@ package Test::Net::Async::Webservice::DHL;
 use strict;
 use warnings;
 use Test::Most;
+use Test::File::ShareDir -share => {
+    -dist => { 'Net-Async-Webservice-DHL' => 'share/' },
+};
 use Data::Printer;
 use Net::Async::Webservice::DHL::Address;
 
@@ -30,16 +33,16 @@ sub test_it {
         is($dhl->base_url,$test_url,'test proxy same as before');
     };
 
-    subtest 'address validation' => sub {
+    subtest 'capability' => sub {
         my $from = Net::Async::Webservice::DHL::Address->new({
             country_code => 'GB',
             postal_code => 'SE7 7RU',
             city => 'London',
         });
         my $to = Net::Async::Webservice::DHL::Address->new({
-            country_code => 'GB',
-            postal_code => 'BN1 9RF',
-            city => 'London',
+            country_code => 'DE',
+            postal_code => '40217',
+            city => "D\x{fc}sseldorf",
         });
 
         $dhl->get_capability({
@@ -51,15 +54,14 @@ sub test_it {
         })->then(
             sub {
                 my ($response) = @_;
-                note p $response;
                 cmp_deeply(
                     $response,
                     {
                         GetCapabilityResponse => {
                             BkgDetails => [{
                                 DestinationServiceArea => {
-                                    FacilityCode    => "LGW",
-                                    ServiceAreaCode => "LGW"
+                                    FacilityCode    => "DUS",
+                                    ServiceAreaCode => "DUS"
                                 },
                                 OriginServiceArea      => {
                                     FacilityCode    => "LCY",
@@ -71,7 +73,7 @@ sub test_it {
                             Srvs => {
                                 Srv => superbagof(
                                     {
-                                        GlobalProductCode => 'N',
+                                        GlobalProductCode => 'K',
                                         MrkSrv => ignore(),
                                     },
                                     {
@@ -79,7 +81,11 @@ sub test_it {
                                         MrkSrv => ignore(),
                                     },
                                     {
-                                        GlobalProductCode => '1',
+                                        GlobalProductCode => 'T',
+                                        MrkSrv => ignore(),
+                                    },
+                                    {
+                                        GlobalProductCode => 'U',
                                         MrkSrv => ignore(),
                                     },
                                 ),
@@ -102,15 +108,14 @@ sub test_it {
         })->then(
             sub {
                 my ($response) = @_;
-                note p $response;
                 cmp_deeply(
                     $response,
                     {
                         GetCapabilityResponse => {
                             BkgDetails => [{
                                 DestinationServiceArea => {
-                                    FacilityCode    => "LGW",
-                                    ServiceAreaCode => "LGW"
+                                    FacilityCode    => "DUS",
+                                    ServiceAreaCode => "DUS"
                                 },
                                 OriginServiceArea      => {
                                     FacilityCode    => "LCY",
@@ -136,7 +141,7 @@ sub test_it {
         )->get;
     };
 
-    subtest 'bad address' => sub {
+    subtest 'capability, bad address' => sub {
         my $from = Net::Async::Webservice::DHL::Address->new({
             country_code => 'GB',
             postal_code => 'SE7 7RU',
@@ -157,7 +162,6 @@ sub test_it {
         })->then(
             sub {
                 my ($response) = @_;
-                note p $response;
                 cmp_deeply(
                     $response,
                     {
@@ -177,6 +181,83 @@ sub test_it {
             }
         )->get;
     };
+
+    subtest 'route request' => sub {
+        my $addr = Net::Async::Webservice::DHL::Address->new({
+            country_code => 'GB',
+            postal_code => 'SE7 7RU',
+            city => 'London',
+        });
+
+        $dhl->route_request({
+            region_code => 'EU',
+            address => $addr,
+            routing_type => 'D',
+            origin_country_code => 'GB',
+        })->then(
+            sub {
+                my ($response) = @_;
+                cmp_deeply(
+                    $response,
+                    {
+                        RegionCode => 'EU',
+                        GMTNegativeIndicator => 'N',
+                        GMTOffset => any('01:00','00:00'),
+                        ServiceArea => {
+                            ServiceAreaCode => 'LCY',
+                            Description => ignore(),
+                        },
+                        Response => ignore(),
+                    },
+                    'response is shaped ok',
+                );
+                return Future->wrap();
+            },
+            sub {
+                note p @_;
+                fail 'Got an error response';
+                return Future->wrap();
+            },
+        )->get;
+
+        $addr = Net::Async::Webservice::DHL::Address->new({
+            country_code => 'GB',
+            postal_code => 'XX1 2YY',
+            city => 'London',
+        });
+
+        $dhl->route_request({
+            region_code => 'EU',
+            address => $addr,
+            routing_type => 'D',
+            origin_country_code => 'GB',
+        })->then(
+            sub {
+                note p @_;
+                fail 'Got a non-error response';
+                return Future->wrap();
+            },
+            sub {
+                my ($exception) = @_;
+                cmp_deeply(
+                    $exception,
+                    all(
+                        isa('Net::Async::Webservice::DHL::Exception::DHLError'),
+                        methods(
+                            error => superhashof({
+                                Condition => superbagof(
+                                    map { superhashof({ConditionCode=>$_}) }
+                                        qw(RT0007 RT0004),
+                                ),
+                            }),
+                        ),
+                    ),
+                    'exception is shaped ok',
+                );
+                return Future->wrap();
+            }
+        )->get;
+    };
 }
 
 1;
